[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula A"}},"key":"1D504"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula B"}},"key":"1D505"},{"key":"212D","mappings":{"default":{"default":"Fraktur mayúscula C"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula D"}},"key":"1D507"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula E"}},"key":"1D508"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula F"}},"key":"1D509"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula G"}},"key":"1D50A"},{"key":"210C","mappings":{"default":{"default":"Fraktur mayúscula H"}},"category":"Lu"},{"key":"2111","mappings":{"default":{"default":"Fraktur mayúscula I"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula J"}},"key":"1D50D"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula K"}},"key":"1D50E"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula L"}},"key":"1D50F"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula M"}},"key":"1D510"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula N"}},"key":"1D511"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula O"}},"key":"1D512"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula P"}},"key":"1D513"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula Q"}},"key":"1D514"},{"key":"211C","mappings":{"default":{"default":"Fraktur mayúscula R"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula S"}},"key":"1D516"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula T"}},"key":"1D517"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula U"}},"key":"1D518"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula V"}},"key":"1D519"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula W"}},"key":"1D51A"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula X"}},"key":"1D51B"},{"category":"Lu","mappings":{"default":{"default":"Fraktur mayúscula Y"}},"key":"1D51C"},{"key":"2128","mappings":{"default":{"default":"Fraktur mayúscula Z"}},"category":"Lu"},{"category":"Ll","mappings":{"default":{"default":"Fraktur a"}},"key":"1D51E"},{"category":"Ll","mappings":{"default":{"default":"Fraktur b"}},"key":"1D51F"},{"category":"Ll","mappings":{"default":{"default":"Fraktur c"}},"key":"1D520"},{"category":"Ll","mappings":{"default":{"default":"Fraktur d"}},"key":"1D521"},{"category":"Ll","mappings":{"default":{"default":"Fraktur e"}},"key":"1D522"},{"category":"Ll","mappings":{"default":{"default":"Fraktur f"}},"key":"1D523"},{"category":"Ll","mappings":{"default":{"default":"Fraktur g"}},"key":"1D524"},{"category":"Ll","mappings":{"default":{"default":"Fraktur h"}},"key":"1D525"},{"category":"Ll","mappings":{"default":{"default":"Fraktur i"}},"key":"1D526"},{"category":"Ll","mappings":{"default":{"default":"Fraktur j"}},"key":"1D527"},{"category":"Ll","mappings":{"default":{"default":"Fraktur k"}},"key":"1D528"},{"category":"Ll","mappings":{"default":{"default":"Fraktur l"}},"key":"1D529"},{"category":"Ll","mappings":{"default":{"default":"Fraktur m"}},"key":"1D52A"},{"category":"Ll","mappings":{"default":{"default":"Fraktur n"}},"key":"1D52B"},{"category":"Ll","mappings":{"default":{"default":"Fraktur o"}},"key":"1D52C"},{"category":"Ll","mappings":{"default":{"default":"Fraktur p"}},"key":"1D52D"},{"category":"Ll","mappings":{"default":{"default":"Fraktur q"}},"key":"1D52E"},{"category":"Ll","mappings":{"default":{"default":"Fraktur r"}},"key":"1D52F"},{"category":"Ll","mappings":{"default":{"default":"Fraktur s"}},"key":"1D530"},{"category":"Ll","mappings":{"default":{"default":"Fraktur t"}},"key":"1D531"},{"category":"Ll","mappings":{"default":{"default":"Fraktur u"}},"key":"1D532"},{"category":"Ll","mappings":{"default":{"default":"Fraktur v"}},"key":"1D533"},{"category":"Ll","mappings":{"default":{"default":"Fraktur w"}},"key":"1D534"},{"category":"Ll","mappings":{"default":{"default":"Fraktur x"}},"key":"1D535"},{"category":"Ll","mappings":{"default":{"default":"Fraktur y"}},"key":"1D536"},{"category":"Ll","mappings":{"default":{"default":"Fraktur z"}},"key":"1D537"}]
